class DiscreteOperatorCounter:

    def __init__(self, n: int):
        self.n = n

    def count_operators(self, **kwargs) -> int:
        """
        Counts the number of discrete operators defined over the finite chain Ln.

        Returns:
            An integer, representing the cardinality of the set of that discrete operators.
        """
        pass
